==> python-gestpay-0.1.1.tar.gz: python-gestpay-0.1.1/pygestpay/currencies.py <==
GPAY_CURRENCIES = {  
   "CAD":{  
      "UICCode":"12",
      "ISO":"124",
      "description":"Canadian"
   },
   "NZD":{  
      "UICCode":"113",
      "ISO":"554",
      "description":"New"
   },
   "IDR":{  
      "UICCode":"123",
      "ISO":"360",
      "description":"Indonesian"
   },
   "AUD":{  
      "UICCode":"109",
      "ISO":"36",
      "description":"Australian"
   },
   "JPY":{  
      "UICCode":"71",
      "ISO":"392",
      "description":"Japanese"
   },
   "THB":{  
      "UICCode":"73",
      "ISO":"764",
      "description":"Thai"
   },
   "HKD":{  
      "UICCode":"103",
      "ISO":"344",
      "description":"Hong"
   },
   "NGN":{  
      "UICCode":"81",
      "ISO":"566",
      "description":"Nigerian"
   },
   "NOK":{  
      "UICCode":"8",
      "ISO":"578",
      "description":"Norwegian"
   },
   "UAH":{  
      "UICCode":"241",
      "ISO":"980",
      "description":"Ukrainian"
   },
   "RON":{  
      "UICCode":"270",
      "ISO":"946",
      "description":"Romanian"
   },
   "HUF":{  
      "UICCode":"153",
      "ISO":"348",
      "description":"Hungarian"
   },
   "ISK":{  
      "UICCode":"62",
      "ISO":"352",
      "description":"Icelandic"
   },
   "ILS":{  
      "UICCode":"203",
      "ISO":"376",
      "description":"Israeli"
   },
   "CZK":{  
      "UICCode":"223",
      "ISO":"203",
      "description":"Czech"
   },
   "VND":{  
      "UICCode":"145",
      "ISO":"704",
      "description":"Vietnamese"
   },
   "INR":{  
      "UICCode":"31",
      "ISO":"356",
      "description":"Indian"
   },
   "PHP":{  
      "UICCode":"66",
      "ISO":"608",
      "description":"Philippine"
   },
   "HRK":{  
      "UICCode":"229",
      "ISO":"191",
      "description":"Croatian"
   },
   "PKR":{  
      "UICCode":"26",
      "ISO":"586",
      "description":"Pakistani"
   },
   "PLN":{  
      "UICCode":"237",
      "ISO":"985",
      "description":"Polish"
   },
   "EUR":{  
      "UICCode":"242",
      "ISO":"978",
      "description":"Euro"
   },
   "ZAR":{  
      "UICCode":"82",
      "ISO":"710",
      "description":"South"
   },
   "SEK":{  
      "UICCode":"9",
      "ISO":"752",
      "description":"Swedish"
   },
   "BGN":{  
      "UICCode":"262",
      "ISO":"975",
      "description":"Bulgarian"
   },
   "SGD":{  
      "UICCode":"124",
      "ISO":"702",
      "description":"Singapore"
   },
   "CHF":{  
      "UICCode":"3",
      "ISO":"756",
      "description":"Swiss"
   },
   "BRL":{  
      "UICCode":"234",
      "ISO":"986",
      "description":"Brazilian"
   },
   "AED":{  
      "UICCode":"187",
      "ISO":"784",
      "description":"United"
   },
   "SAR":{  
      "UICCode":"75",
      "ISO":"682",
      "description":"Saudi"
   },
   "TWD":{  
      "UICCode":"143",
      "ISO":"901",
      "description":"New"
   },
   "KRW":{  
      "UICCode":"119",
      "ISO":"410",
      "description":"South"
   },
   "GBP":{  
      "UICCode":"2",
      "ISO":"826",
      "description":"Pound"
   },
   "RUB":{  
      "UICCode":"244",
      "ISO":"643",
      "description":"Russian"
   },
   "USD":{  
      "UICCode":"1",
      "ISO":"840",
      "description":"United"
   },
   "CNY":{  
      "UICCode":"144",
      "ISO":"156",
      "description":"Chinese"
   },
   "DKK":{  
      "UICCode":"7",
      "ISO":"208",
      "description":"Danish"
   },
   "TRY":{  
      "UICCode":"267",
      "ISO":"949",
      "description":"Turkish"
   },
   "MYR":{  
      "UICCode":"55",
      "ISO":"458",
      "description":"Malaysian"
   }
}

==> python-gestpay-0.2.0.tar.gz: python-gestpay-0.2.0/pygestpay/currencies.py <==
GPAY_CURRENCIES = {  
   "CAD":{  
      "UICCode":12,
      "ISO":"124",
      "description":"Canadian"
   },
   "NZD":{  
      "UICCode":113,
      "ISO":"554",
      "description":"New"
   },
   "IDR":{  
      "UICCode":123,
      "ISO":"360",
      "description":"Indonesian"
   },
   "AUD":{  
      "UICCode":109,
      "ISO":"36",
      "description":"Australian"
   },
   "JPY":{  
      "UICCode":71,
      "ISO":"392",
      "description":"Japanese"
   },
   "THB":{  
      "UICCode":73,
      "ISO":"764",
      "description":"Thai"
   },
   "HKD":{  
      "UICCode":103,
      "ISO":"344",
      "description":"Hong"
   },
   "NGN":{  
      "UICCode":81,
      "ISO":"566",
      "description":"Nigerian"
   },
   "NOK":{  
      "UICCode":8,
      "ISO":"578",
      "description":"Norwegian"
   },
   "UAH":{  
      "UICCode":241,
      "ISO":"980",
      "description":"Ukrainian"
   },
   "RON":{  
      "UICCode":270,
      "ISO":"946",
      "description":"Romanian"
   },
   "HUF":{  
      "UICCode":153,
      "ISO":"348",
      "description":"Hungarian"
   },
   "ISK":{  
      "UICCode":62,
      "ISO":"352",
      "description":"Icelandic"
   },
   "ILS":{  
      "UICCode":203,
      "ISO":"376",
      "description":"Israeli"
   },
   "CZK":{  
      "UICCode":223,
      "ISO":"203",
      "description":"Czech"
   },
   "VND":{  
      "UICCode":145,
      "ISO":"704",
      "description":"Vietnamese"
   },
   "INR":{  
      "UICCode":31,
      "ISO":"356",
      "description":"Indian"
   },
   "PHP":{  
      "UICCode":66,
      "ISO":"608",
      "description":"Philippine"
   },
   "HRK":{  
      "UICCode":229,
      "ISO":"191",
      "description":"Croatian"
   },
   "PKR":{  
      "UICCode":26,
      "ISO":"586",
      "description":"Pakistani"
   },
   "PLN":{  
      "UICCode":237,
      "ISO":"985",
      "description":"Polish"
   },
   "EUR":{  
      "UICCode":242,
      "ISO":"978",
      "description":"Euro"
   },
   "ZAR":{  
      "UICCode":82,
      "ISO":"710",
      "description":"South"
   },
   "SEK":{  
      "UICCode":9,
      "ISO":"752",
      "description":"Swedish"
   },
   "BGN":{  
      "UICCode":262,
      "ISO":"975",
      "description":"Bulgarian"
   },
   "SGD":{  
      "UICCode":124,
      "ISO":"702",
      "description":"Singapore"
   },
   "CHF":{  
      "UICCode":3,
      "ISO":"756",
      "description":"Swiss"
   },
   "BRL":{  
      "UICCode":234,
      "ISO":"986",
      "description":"Brazilian"
   },
   "AED":{  
      "UICCode":187,
      "ISO":"784",
      "description":"United"
   },
   "SAR":{  
      "UICCode":75,
      "ISO":"682",
      "description":"Saudi"
   },
   "TWD":{  
      "UICCode":143,
      "ISO":"901",
      "description":"New"
   },
   "KRW":{  
      "UICCode":119,
      "ISO":"410",
      "description":"South"
   },
   "GBP":{  
      "UICCode":2,
      "ISO":"826",
      "description":"Pound"
   },
   "RUB":{  
      "UICCode":244,
      "ISO":"643",
      "description":"Russian"
   },
   "USD":{  
      "UICCode":1,
      "ISO":"840",
      "description":"United"
   },
   "CNY":{  
      "UICCode":144,
      "ISO":"156",
      "description":"Chinese"
   },
   "DKK":{  
      "UICCode":7,
      "ISO":"208",
      "description":"Danish"
   },
   "TRY":{  
      "UICCode":267,
      "ISO":"949",
      "description":"Turkish"
   },
   "MYR":{  
      "UICCode":55,
      "ISO":"458",
      "description":"Malaysian"
   }
}
